@@ -9,15 +9,23 @@
 .split_chars <- function(x) unlist(strsplit(x, ""))
 
 ## MISC
-only_single_chars <- function(A) {
-  for (i in seq_along(nrow(A))) {
-    for (j in seq_along(ncol(A)))
-      if ( nchar(A[i,j]) != 1L ) return(FALSE)
-  }
-  return(TRUE)
+## only_single_chars <- function(A) {
+##   for (i in seq_along(nrow(A))) {
+##     for (j in seq_along(ncol(A)))
+##       if ( nchar(A[i,j]) != 1L ) return(FALSE)
+##   }
+##   return(TRUE)
+## }
+
+only_chars <- function(A) {
+  all(apply(A, 2L, function(x) {
+    nc <- nchar(paste0(x, collapse = ""))
+    nc == nrow(A)
+  }))
 }
 
 
+
 ## ---------------------------------------------------------
 ##                     EXPORTED HELPERS
 ## ---------------------------------------------------------
@@ -29,9 +37,9 @@ only_single_chars <- function(A) {
 #' @param x Data frame or matrix of characters
 #' @examples
 #' d <- data.frame(x = c("11", "2"), y = c("2", "11"))
-#' to_single_chars(d)
+#' to_chars(d)
 #' @export
-to_single_chars <- function(x) {
+to_chars <- function(x) {
   # Implicitly assumes that no columns has more than length(chars) = 62 unique levels
   # Consider saving the olde levels so we can retrive them again easily later
   apply(x, 2, function(z) {
